#
# spec file for package warewulf4
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global tftpdir /srv/tftpboot
%global srvdir %{_sharedstatedir}
#%%global githash 5b0de8ea5397ca42584335517fd4959d7ffe3da5

ExclusiveArch:  x86_64 aarch64

Name:           warewulf4
Version:        4.5.6
Release:        2.1
Summary:        A suite of tools for clustering
License:        BSD-3-Clause
Group:          Productivity/Clustering/Computing
URL:            https://warewulf.org
Source0:        warewulf-%{version}.tar
Source1:        vendor.tar.xz
Source5:        warewulf4-rpmlintrc
Source10:       config-ww4.sh
Source11:       adjust_overlays.sh
Source20:       README.dnsmasq
Patch0:         added-cow-option-to-bind.patch

# no firewalld in sle12
%if 0%{?sle_version} >= 150000 || 0%{?suse_version} > 1500
BuildRequires:  firewalld
%endif
BuildRequires:  distribution-release
BuildRequires:  dracut
BuildRequires:  go >= 1.20
BuildRequires:  golang-packaging
BuildRequires:  libgpg-error-devel
BuildRequires:  make
BuildRequires:  munge
BuildRequires:  sysuser-tools
BuildRequires:  tftp
BuildRequires:  yq
BuildRequires:  pkgconfig(gpgme)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%sysusers_requires
Requires:       %{name}-overlay = %{version}
Requires:       ipxe-bootimgs
Requires:       pigz
Requires:       tftp
Requires:       ( dhcp-server or dnsmasq )
Suggests:       dhcp-server
Recommends:     bash-completion
Recommends:     ipmitool
Recommends:     nfs-kernel-server

%{?go_nostrip}

%description
Warewulf v4 combines ultra scalability, flexibility, and simplicity with being
light weight, non-intrusive, and a great tool for scientists and seasoned
system administrators alike. Warewulf empowers you to scalably and easily
manage thousands of compute resources.

%package overlay
# Smells like a circular dependcy, but needed in this case as the
# files belong to the warewulf user
Requires(pre):  %{name} = %version
Summary:        Default overlay for warewulf
Group:          Productivity/Clustering/Computing

%description overlay
Includes the default overlays so that they can be updated seprately.

%package man
Supplements:    %{name} = %version
Summary:        Warewulf4 Man Pages
BuildArch:      noarch

%description man
Man pages for warewulf4.

%package overlay-slurm
Summary:        Configuration template for slurm
Requires:       %{name} = %{version}
Requires:       slurm
BuildArch:      noarch
Obsoletes:      warewulf4-slurm <= 4.4.0
Provides:       warewulf4-slurm = %version

%description overlay-slurm
This package install the necessary configuration files in order to run a slurm
cluster on the configured warewulf nodes.

%package dracut
Summary:        Dracut module for loading a Warewulf container image
BuildArch:      noarch

Requires:       dracut

%description dracut
This subpackage contains a dracut module that can be used to generate
an initramfs that can fetch and boot a Warewulf container image from a
Warewulf server.

%prep
%autosetup -a1 -p1 -n warewulf-%{version}
echo %{version} > VERSION

%build
export OFFLINE_BUILD=1
export IPXESOURCE=%{_datadir}/ipxe
export GOFLAGS="-buildmode=pie"
make defaults \
    PREFIX=%{_prefix} \
    BINDIR=%{_bindir} \
    SYSCONFDIR=%{_sysconfdir} \
    DATADIR=%{_datadir} \
    LOCALSTATEDIR=%{_sharedstatedir} \
    SHAREDSTATEDIR=%{_sharedstatedir} \
    MANDIR=%{_mandir} \
    INFODIR=%{_infodir} \
    DOCDIR=%{_docdir} \
    SRVDIR=%{srvdir} \
    TFTPDIR=%{tftpdir} \
    SYSTEMDDIR=%{_unitdir} \
    BASHCOMPDIR=/etc/bash_completion.d/ \
    FIREWALLDDIR=/usr/lib/firewalld/services \
    WWCLIENTDIR=/warewulf
make %{?_smp_mflags} build \
    PREFIX=%{_prefix} \
    BINDIR=%{_bindir} \
    SYSCONFDIR=%{_sysconfdir} \
    DATADIR=%{_datadir} \
    LOCALSTATEDIR=%{_sharedstatedir} \
    SHAREDSTATEDIR=%{_sharedstatedir} \
    MANDIR=%{_mandir} \
    INFODIR=%{_infodir} \
    DOCDIR=%{_docdir} \
    SRVDIR=%{srvdir} \
    TFTPDIR=%{tftpdir} \
    SYSTEMDDIR=%{_unitdir} \
    BASHCOMPDIR=/etc/bash_completion.d/ \
    FIREWALLDDIR=/usr/lib/firewalld/services \
    WWCLIENTDIR=/warewulf

%install
# we have a broken symlink for wwclient
export NO_BRP_STALE_LINK_ERROR=yes
export IPXESOURCE=%{_datadir}/ipxe
# overlays will end up here
export OFFLINE_BUILD=1
export LOCALSTATEDIR=%{_localstatedir}/lib
%{makeinstall}

# cleanup
mkdir -p %{buildroot}%{_sbindir}/
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcwarewulfd

mkdir -p %{buildroot}%{_datadir}/bash-completion/completions
mv -v %{buildroot}%{_sysconfdir}/bash_completion.d/wwctl \
  %{buildroot}%{_datadir}/bash-completion/completions/wwctl
# copy the LICESNSE.md via %%doc
rm -f %{buildroot}/usr/share/doc/packages/warewulf/LICENSE.md
cp %{S:20} .

# use ipxe-bootimgs images from distribution
yq e '
  .tftp.["systemd name"] = "tftp.socket" |
  .tftp.ipxe."00:00" = "undionly.kpxe" |
  .tftp.ipxe."00:07" = "ipxe-x86_64.efi" |
  .tftp.ipxe."00:09" = "ipxe-x86_64.efi" |
  .tftp.ipxe."00:0B" = "snp-arm64.efi" |
  .["container mounts"] += {"source": "/etc/SUSEConnect", "dest": "/etc/SUSEConnect", "readonly": true} |
  .["container mounts"] += {"source": "/etc/zypp/credentials.d/SCCcredentials", "dest": "/etc/zypp/credentials.d/SCCcredentials", "readonly": true}' \
  -i %{buildroot}%{_sysconfdir}/warewulf/warewulf.conf
# disable suse net-naming
#yq -e '
#  .defaultnode.kernel.args="quiet crashkernel=no net.ifnames=1" |
#  del(.defaultnode.["boot method"] )' \
#  -i %{buildroot}%{_datadir}/warewulf/defaults.conf
# SUSE starts user UIDs at 1000
sed -i -e 's@\(.* \$_UID \(>\|-ge\) \)500\(.*\)@\11000\3@' %{buildroot}%{_localstatedir}/lib/warewulf/overlays/host/rootfs/etc/profile.d/ssh_setup.*sh.ww
# fix dhcp for SUSE
mv %{buildroot}%{_localstatedir}/lib/warewulf/overlays/host/rootfs/etc/dhcp/dhcpd.conf.ww %{buildroot}%{_localstatedir}/lib/warewulf/overlays/host/rootfs/etc/dhcpd.conf.ww
rmdir %{buildroot}%{_localstatedir}/lib/warewulf/overlays/host/rootfs/etc/dhcp

# create systemuser
echo "u warewulf -" > system-user-%{name}.conf
echo "g warewulf -" >> system-user-%{name}.conf
%sysusers_generate_pre system-user-%{name}.conf %{name} system-user-%{name}.conf
install -D -m 644 system-user-%{name}.conf %{buildroot}%{_sysusersdir}/system-user-%{name}.conf
install -D -m 755 %{S:10} %{buildroot}%{_datadir}/warewulf/scripts/config-warewulf.sh
install -D -m 755 %{S:11} %{buildroot}%{_datadir}/warewulf/scripts/%{basename:S:11}

# get the slurm package ready
mkdir -p %{buildroot}%{_localstatedir}/lib/warewulf/overlays/host/rootfs/etc/slurm
mv %{buildroot}%{_sysconfdir}/warewulf/examples/slurm.conf.ww %{buildroot}%{_localstatedir}/lib/warewulf/overlays/host/rootfs/etc/slurm
mkdir -p %{buildroot}%{_localstatedir}/lib/warewulf/overlays/generic/rootfs/etc/munge
cat >  %{buildroot}%{_localstatedir}/lib/warewulf/overlays/generic/rootfs/etc/munge/munge.key.ww <<EOF
{{ Include "/etc/munge/munge.key" -}}
EOF
chmod 600 %{buildroot}%{_localstatedir}/lib/warewulf/overlays/generic/rootfs/etc/munge/munge.key.ww
mkdir -p %{buildroot}%{_localstatedir}/lib/warewulf/overlays/generic/rootfs/etc/slurm
cat >  %{buildroot}%{_localstatedir}/lib/warewulf/overlays/generic/rootfs/etc/slurm/slurm.conf.ww <<EOF
{{ Include "/etc/slurm/slurm.conf" }}
EOF
# move the other example templates for client overlays to package documentation
mkdir -p %{buildroot}/%{_defaultdocdir}/%{name}
mv %{buildroot}/%{_sysconfdir}/warewulf/examples %{buildroot}%{_defaultdocdir}/%{name}/example-templates

%pre -f %{name}.pre
%service_add_pre warewulfd.service

%post
%service_add_post warewulfd.service
%{_datadir}/warewulf/scripts/config-warewulf.sh

%preun
%service_del_preun warewulfd.service

%postun
%service_del_postun warewulfd.service

%posttrans overlay
%{_datadir}/warewulf/scripts/%{basename:S:11}

%files
%defattr(-,root,root)
%doc README.md
%doc README.dnsmasq
%license LICENSE.md
%{_datadir}/bash-completion/completions/wwctl
%attr(0755, root, warewulf) %dir %{_sysconfdir}/warewulf
%attr(0755, root, warewulf) %dir %{_defaultdocdir}/%{name}/example-templates
%config(noreplace) %{_sysconfdir}/warewulf/nodes.conf
%config(noreplace) %{_sysconfdir}/warewulf/warewulf.conf
%config(noreplace) %{_sysconfdir}/warewulf/grub
%config(noreplace) %{_sysconfdir}/warewulf/ipxe
%{_sysconfdir}/logrotate.d/warewulfd.conf
%{_defaultdocdir}/%{name}/example-templates
%{_prefix}/lib/firewalld/services/warewulf.xml
%exclude %{_datadir}/warewulf/overlays
%exclude %{_datadir}/warewulf/scripts/%{basename:S:11}
%{_bindir}/wwctl
%{_sbindir}/rcwarewulfd
%{_unitdir}/warewulfd.service
%{_sysusersdir}/system-user-%{name}.conf
%{_datadir}/warewulf
%ghost %{_sysconfdir}/profile.d/ssh_setup.sh
%ghost %{_sysconfdir}/profile.d/ssh_setup.csh

%files man
%{_mandir}/man1/wwctl*1.gz
%{_mandir}/man5/*conf*gz

%files overlay
# The configuration files in this location are for the compute
# nodes, so when modified we do not replace them as sensible
# admin will read the changelog
%{_localstatedir}/lib/warewulf/overlays
%dir %{_localstatedir}/lib/warewulf
%config(noreplace) %{_localstatedir}/lib/warewulf/overlays
%{_datadir}/warewulf/scripts/%{basename:S:11}
%exclude %{_localstatedir}/lib/warewulf/overlays/host/rootfs/etc/slurm
%exclude %{_localstatedir}/lib/warewulf/overlays/generic/rootfs/etc/slurm
%exclude %{_localstatedir}/lib/warewulf/overlays/generic/rootfs/etc/munge

%files overlay-slurm
%dir %{_localstatedir}/lib/warewulf/overlays/host/rootfs/etc/slurm
%{_localstatedir}/lib/warewulf/overlays/host/rootfs/etc/slurm/slurm.conf.ww
%dir %{_localstatedir}/lib/warewulf/overlays/generic/rootfs/etc/slurm
%{_localstatedir}/lib/warewulf/overlays/generic/rootfs/etc/slurm/slurm.conf.ww
%dir %{_localstatedir}/lib/warewulf/overlays/generic/rootfs/etc/munge
%{_localstatedir}/lib/warewulf/overlays/generic/rootfs/etc/munge/munge.key.ww
%dir %attr(0700,munge,munge) %{_localstatedir}/lib/warewulf/overlays/generic/rootfs/etc/munge
%attr(0600,munge,munge) %config(noreplace) %{_localstatedir}/lib/warewulf/overlays/generic/rootfs/etc/munge/munge.key.ww

%files dracut
%defattr(-, root, root)
%dir %{_prefix}/lib/dracut/modules.d/90wwinit
%{_prefix}/lib/dracut/modules.d/90wwinit/*.sh

%changelog
* Thu Aug 22 2024 Christian Goll <cgoll@suse.com>
- added option which allows to copy in file on wwctl container exec
  and keep them, if they were modified
- added added-cow-option-to-bind.patch
* Fri Aug  9 2024 cgoll@suse.com
- Update to version 4.5.6 with following changes:
  * Show more information during wwctl container <shell|exec> about
    when and if the container image will be rebuilt.
  * Command-line completion for wwctl overlay <edit|delete|chmod|chown>.
  * Display an error during boot if no container is defined.
  * wwctl conaitner list --kernel shows the kernel detected for each container.
  * wwctl container list --size shows the uncompressed size of each container.
  - -compressed shows the compressed size, and --chroot shows the size of the container i
    source on the server.
  * Add a logrotate config for warewulfd.log.
- removed following patches as accepted upstream:
  * empty-container.patch
  * enhanced-cont-list.patch
  * fix-overlay-built.patch
  * issue-motd.patch
  * oci-vars.patch
  * verbose-exec.patch
* Tue Jul  9 2024 Christian Goll <cgoll@suse.com>
- updated to 4.5.5 with following changes:
  * mount `/sys` and `/run` on `wwctl container exec` to enabled
    SUSEConnect (bsc#1227289)
  * don't want on NIS style passwd line (bsc#1227250)
  * wwctl import can have `passwd` and `user` argument (bsc#1227340)
  * add net.ifnames=1 to default kernel parameters (bsc#1226654)
  * be more verbose if container is rebuild (bsc#1227646)
  * issue like message in motd (bsc#1227478)
- removed wwctl-configure-all-calls-SSH-keys.patch as included
  upstream
- added following not yet accepted upstream patches:
  * empty-container.patch
  * enhanced-cont-list.patch
  * fix-overlay-built.patch
  * oci-vars.patch
  * issue-motd.patch
  * verbose-exec.patch
* Mon May 27 2024 Christian Goll <cgoll@suse.com>
- added wwctl-configure-all-calls-SSH-keys.patch to fix
  (bsc#1225402)
* Tue May 14 2024 Christian Goll <cgoll@suse.com>
- update to 4.5.2 with followin changes:
  * Reorder dnsmasq config to put iPXE last
  * Update a dependency to fix CVE-2024-3727 (bsc#1224124)
* Mon May 13 2024 Christian Goll <cgoll@suse.com>
- updated to version 4.5.1 with following changes
  * wwctl [profile|node] list -a handles now slices correclty
  * Fix a locking issue with concurrent read/writes for node status
- removed fixed-ShimFind-for-aarch64.patch as incoperated upstreams
- Remove API package as use of this wasn't documented
* Fri Apr  5 2024 Christian Goll <cgoll@suse.com>
- use tftp.socket for activation not service (bsc#1216994)
* Tue Mar 26 2024 Egbert Eich <eich@suse.com>
- %%ghost /etc/profile.d/setup-ssh.[c]sh
* Mon Mar 25 2024 Christian Goll <cgoll@suse.com>
- updated to 4.5.0 which has no functional changes to rc2
- added fixed-ShimFind-for-aarch64.patch to fix (bsc#1221133)
* Fri Mar 22 2024 Egbert Eich <eich@suse.com>
- Allow to install dnsmasq as an alternative to dhcp-server.
- Set minimum UID value for user UIDs to 1000 (boo#1221886).
- Make dependencies warewulf package version dependent. This
  helps to keep the resolver to mix different packages from
  different versions.
- On upgrade from older versions move files from
  `/usr/share/warewulf/overlays/` to
  `/var/lib/warewulf/overlays/*/rootfs/`
  * Added: adjust_overlays.sh.
* Thu Feb 22 2024 Christian Goll <cgoll@suse.com>
- updated to 4.5.0rc2. This fixes:
  * `wwctl node list` panics if a node uses a profile with a
    network which isn't present on this node (bsc#1220189).
* Mon Feb 19 2024 Christian Goll <cgoll@suse.com>
- updated to 4.5.0rc1 from upstream with following change:
  * all overlays reside now under a `rootfs` diretory e.g.
    the host overlays reside now under
    `/var/lib/warewulf/host/rootfs`
    This has the advantage that the `rootfs` can be under a version
    control, without the effect that the meta files e.g. `.git` will
    show up in the rendered overlays.
- removed patches:
  * clean-warewulf-conf.patch
  * dnsmasq-template-move.patch
  * removed vendor.tar.gz
* Mon Feb 19 2024 Egbert Eich <eich@suse.com>
- Move example templates for client overlays to example-templates/
  in the package documentation.
* Wed Feb  7 2024 Egbert Eich <eich@suse.com>
- Rename: warewulf4-doc -> warewulf4-man.
- Rename: warewulf4-slurm -> warewulf4-overlay-slurm
- Set warewulf4-man and warewulf4-overlay-slurm to noarch.
- Use bash for config-warewulf.sh
- Improved rpmlint filters.
* Wed Jan 24 2024 Christian Goll <cgoll@suse.com>
- make only overlay dir beeing config files
* Fri Jan 19 2024 Christian Goll <cgoll@suse.com>
- moved to git archive hash as source in order to be reproducible
- added vendor.tar.gz as git hash source doesn't have vendoring
- removed grub-boot.patch as incorporated upstreams
* Wed Jan 17 2024 Christian Goll <cgoll@suse.com>
- added documentation for replacing dhcpd and tftp with dnsmasq
  as README.dnsmasq (jira#HPC-65)
- added following patches:
  * clean-warewulf-conf.patch
  * dnsmasq-template-move.patch
* Thu Dec 21 2023 Christian Goll <cgoll@suse.com>
- updated to v4.5.0rc0 pre release with following new features:
  * disks, partitions and file systems can set in the configration
    and if ignition is present in the container, changes to the disks will be
    made
  * grub can be used as alternative boot method instead of iPXE. The
    grub binairy is extracted from the container and shim is executed before
    the grub. This enables secure boot
  * wwctl has now the genconfig subcommand which will print/create
    valid configurations
  * all paths e.g the overlay dir, can now be configured in warewulf.conf
- notable bug fixes are:
  * Fixed a bug where profile tags were erroneously overridden by empty node
    values.
  * Fixed bug where tags from profiles weren't rendered
- added grub-boot.patch which includes the not merged grub support
- removed make-ipxe-binary-source-configureable.patch
  CreateMt-Targets.patch,
  Fix-for-CVE-2022-41723.patch as incoperated upstream
* Thu Oct 12 2023 Christian Goll <cgoll@suse.com>
- check if automatic configured ip range doesn'y contain ip address
  of ww4 host (bsc#1215583)
* Thu Sep 21 2023 Christian Goll <cgoll@suse.com>
- removed the upstream ipxe binaries
* Thu Feb 16 2023 Christian Goll <cgoll@suse.com>
- added Fix-for-CVE-2022-41723.patch in order to fix CVE-2022-41723
  (bsc#1208301)
  Note: an updated vendor.tar.gz is also required
- use the static dhpd configuration, which means known nodes will not
  only be static configured, but also get their configured ip address
  via dhcp
* Tue Feb  7 2023 Christian Goll <cgoll@suse.com>
- added CreateMt-Targets.patch
  which moonts in resolv.conf and files for SCC registration
- added config-ww4.sh which is used for initial configuration for
  simple network setups
* Tue Jan 31 2023 Egbert Eich <eich@suse.com>
- Add %%sysusers_requires macro to account for missing dependencies
  (boo#1207802).
* Tue Jan 24 2023 Christian Goll <cgoll@suse.com>
- added make-ipxe-binary-source-configureable.patch
- use distro ipxe binaries instead of binaries blobs from the
  warewulf github repo
* Thu Jan 19 2023 Christian Goll <cgoll@suse.com>
- Update to 4.4.0 with following changes:
  * chroots and overlays moved from /var/lib to /usr/share
  * all boolean options need now to have the form --option=true|false
    e.g. wwctl node set node01 --discoverable=true
  * wwctl show --render shows overlay templates as they would be
    rendered on a given target node
* Thu Jan  5 2023 Christian Goll <cgoll@suse.com>
- updated to version v4.4.0 with following changes:
  * Changed internal interacation between the on disk YAML format and the in memory
    format. This enables the command line options to be autogenerated from the datastructures.
    Also this keeps the options for profiles and node set/add commands in strict sync.
  * Added node edit/export/import where the edit command exposes the YAML config for the
    given nodes in an editor. Nodes can also be added with this command. The export command
    simply drops the YAML config for the given nodes. With the import command nodes can be
    imported as YAML or as a CSV file. The CSV file must havr a header in where the first field
    must always be the nodename, the rest of the fields are the same as the long commandline
    options. Network device must have the form net.$NETNAME.$NETOPTION, which would e.g. be
    net.default.ipaddr
  * The default value (like kernel args) are no read in from the configuration file
    defaults.conf. If this file couldn't be read built in default values will be used.
  * Template files for NetworkManager are now present in the wwinit overlay. A interface must
    have the type ethernet or infiniband that these will be brought up by NetworkManager
  * Listings of container via wwctl container list will now show the creation,modification
    date and the size.
  * Initial cut of the warewulf API.
* Tue Jun 21 2022 Christian Goll <cgoll@suse.com>
- fixed symlink dhcpd.conf collision
* Mon Jun 20 2022 Christian Goll <cgoll@suse.com>
- updated to 4.3.0
  * fixed bug which for single node profile set
* Fri Jun 10 2022 Christian Goll <cgoll@suse.com>
- update to 4.3.0rc6 what should the final release candidate
  * using compressed images again, as PXE else would fail
* Thu Apr 14 2022 Christian Goll <cgoll@suse.com>
- update to v4.3.0rc2 with following major changes:
  * Provision interface is not tied to 'eth0' any more. The provision interface
    must be named 'default' now. The file `nodes.yaml' must be changed accordingly.
  * Creating of '/etc/exports' can now be disabled, so that wwctl configure -a
    wont overwrite a existing '/etc/exports'.
  * All configurations files for the host (/etc/exports, /etc/dhcpd.conf,
    /etc/hosts) are now populated from the
    (OVERLAYDIR/host/etc/{exports|dhcpd|hosts}.ww . Also other configuration
    files like prometheus.yml.ww or slurm.conf.ww which depend on the cluster
    nodes can be placed. Also the new templated functions {{ abort }},
    {{ IncludeBlock }} abd {{ no_backup }} are allowed now.
  * nodes and profiles can now have multiple system and runtime overlays, as a
    comma separated list.
  * The overlays of the profile and the nodes are combined.
  * Simple ipv6 support is now enabled. In warewulf.conf the option
    ipaddr6/Ipv6net must be set to enable ipv6. If enabled on of these options
    is set a node will get a derived ipv6 in the scheme ipv6net:ipaddr4. This
    address can also be overwritten for every node
  * Multiple files can now created from a single template.ww file with the {{ file FILENAME }}
    command in the template. The command is expanded to the magic template command
    {{ /* file FILENAME */}} which is picked up by wwctl and everything which comes after this
    magic comment will be written to the file FILENAME. This mechanism is leveraged in the
    configuration files for the network, see ifcfg.xml.ww and ifcgf.ww.
  * Networks can now have arbitrary keys value pairs in the profiles and on the node, so that
    things like bridges and mtu sizes can be set
  * The yaml format for nodes has now sub-keys for ipmi and kernel, old nodes.conf files have to
    to be changed accordingly
  * uids and gids of a container now get synced at import time, so that at least users with the
    same name have the same uid. This is not necessarily needed for warewulf, but services like
    munge.
  * backward compatibility for nodes.conf
  * added file:// uri for importing archived containers
- removed LocalStateDir-is-configureable-to-meet-FHS.patch as implemented upstream
* Thu Oct 28 2021 Christian Goll <cgoll@suse.com>
- updated to findal release 4.2.0 with following bugs fix
  * kernel modules are imported with the right path
* Thu Oct 14 2021 Christian Goll <cgoll@suse.com>
- fixed permissions in overlays
* Mon Oct  4 2021 Christian Goll <cgoll@suse.com>
- updated to warewulf-v4.2.0rc1 with following new features:
  * bash_completion can add nodes, container and other stuff
  * kernels can now have arbitray names
  * using syslog instead of logfile
  * kernels get uncompresses on import
- Utilize sysuser infrastructure to set user/group warewulf
* Tue Aug 31 2021 Christian Goll <cgoll@suse.com>
- updating to actual HEAD on github, as this version incorporates
  some of the patches
- removed patches which are now in upstream:
  * bash_completion.patch
  * build-position-independent-code.patch
  * install-creates-needed-dirs-and-checks-for-systemd.patch
  * added-wicked-xml-configuration.patch
  * added-configureable-ipmiinterface-used-by-ipmitool.patch
  * preserve-ownership-for-overlays.patch
- added patch:
  * added-function-CopyUIDGID-for-file-file-ownerships.patch
* Tue Aug 10 2021 Christian Goll <cgoll@suse.com>
- updated to warewulf-v4.1.0 prerelease instead of HEAD
* Wed Jul 21 2021 Christian Goll <cgoll@suse.com>
- inital commit of warewulf4 which is a rewrite of warewulf in
  go thus the new name
  * including vector.tar.gz which are the deps
  * warewulf.conf is the SUSE specific configuration file
- patches with new functionality, might be included upstream
  * bash_completion.patch
  * build-position-independent-code.patch
  * install-creates-needed-dirs-and-checks-for-systemd.patch
  * LocalStateDir-is-configureable-to-meet-FHS.patch
  * added-wicked-xml-configuration.patch
  * added-configureable-ipmiinterface-used-by-ipmitool.patch
  * preserve-ownership-for-overlays.patch
